Struct diem_types::event::EventKey [−][src]
pub struct EventKey(_);Expand description
A struct that represents a globally unique id for an Event stream that a user can listen to. By design, the lower part of EventKey is the same as account address.
Implementations
Get the account address part in this event key
If this is the ith EventKeycreated byget_creator_address(), return i`
Create a unique handle by using an AccountAddress and a counter.